#
# spec file for package pciutils
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   3
%define lname   libpci%{sover}
Name:           pciutils
Version:        3.13.0
Release:        3.1
Summary:        PCI utilities for the Linux Kernel
License:        GPL-2.0-or-later
Group:          Hardware/Other
URL:            https://mj.ucw.cz/sw/pciutils/
Source:         https://www.kernel.org/pub/software/utils/%{name}/%{name}-%{version}.tar.xz
Source1:        https://www.kernel.org/pub/software/utils/%{name}/%{name}-%{version}.tar.sign
Source2:        baselibs.conf
# https://mj.ucw.cz/pgp.html
Source3:        https://mj.ucw.cz/pgpkey.txt#/%{name}.keyring
Patch0:         pciutils-3.1.9_pkgconfig.patch
Patch1:         pciutils-endianh.patch
Patch2:         pciutils-ocloexec.patch
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libkmod)
BuildRequires:  pkgconfig(zlib)
Requires:       hwdata

%description
lspci: This program displays detailed information about all PCI busses
and devices in the system, replacing the original /proc/pci interface.

setpci: This program allows reading from and writing to PCI device
configuration registers. For example, you can adjust the latency timers
with it.

update-pciids: This program downloads the current version of the
pci.ids file.

%package -n %{lname}
Summary:        PCI utility library
Group:          System/Libraries

%description -n %{lname}
libpci offers access to the PCI configuration space.

%package devel
Summary:        Library and Include Files of the PCI utilities
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
This package contains the files that are necessary for software
development using the PCI utilities.

%prep
%autosetup -p1

%build
%make_build OPT="%{optflags}" PREFIX=%{_prefix} LIBDIR=%{_libdir} SBINDIR=%{_bindir} STRIP="" SHARED="yes"

%install
make install PREFIX=%{buildroot}%{_prefix} SBINDIR=%{buildroot}%{_bindir} \
             ROOT=%{buildroot} MANDIR=%{buildroot}%{_mandir} STRIP="" \
	     SHARED="yes" LIBDIR=%{buildroot}%{_libdir}
chmod 0755 %{buildroot}%{_libdir}/libpci.so.%{sover}
mkdir -p %{buildroot}%{_includedir}/pci
cp -p lib/{pci,header,config,types}.h %{buildroot}%{_includedir}/pci
rm -rf %{buildroot}%{_datadir}/pci.ids*
install -D -m 0644 lib/libpci.pc %{buildroot}%{_libdir}/pkgconfig/libpci.pc
ln -sf %{_libdir}/libpci.so.3 %{buildroot}%{_libdir}/libpci.so

%if 0%{?suse_version} < 1550
mkdir %{buildroot}/sbin
ln -s %{_bindir}/{lspci,setpci,pcilmr} %{buildroot}/sbin
%endif

mkdir %{buildroot}%{_sbindir}
ln -s %{_bindir}/{lspci,setpci,pcilmr} %{buildroot}%{_sbindir}

rm %{buildroot}%{_bindir}/update-pciids
rm %{buildroot}%{_mandir}/man8/update-pciids.8

%check
%make_build tests

%if 0%{?suse_version} >= 1600
%ldconfig_scriptlets -n %{lname}
%else
%post -p /sbin/ldconfig -n %{lname}
%end
%postun -p /sbin/ldconfig -n %{lname}
%end
%endif

%files
%license COPYING
%doc README
%if 0%{?suse_version} < 1550
/sbin/lspci
/sbin/pcilmr
/sbin/setpci
%endif
%{_bindir}/lspci
%{_bindir}/pcilmr
%{_bindir}/setpci
%{_sbindir}/lspci
%{_sbindir}/pcilmr
%{_sbindir}/setpci
%{_mandir}/man7/pcilib.7%{?ext_man}
%{_mandir}/man8/lspci.8%{?ext_man}
%{_mandir}/man8/pcilmr.8%{?ext_man}
%{_mandir}/man8/setpci.8%{?ext_man}
%{_mandir}/man5/pci.ids.5%{?ext_man}

%files -n %{lname}
%license COPYING
%{_libdir}/libpci.so.%{sover}
%{_libdir}/libpci.so.%{sover}.*

%files devel
%license COPYING
%{_includedir}/pci
%{_libdir}/libpci.so
%{_libdir}/pkgconfig/libpci.pc

%changelog
* Thu Mar 13 2025 Peter Simons <psimons@suse.com>
- Synchronize SLE-12 and openSUSE:Factory [jsc#PED-4587].
  The following patches are now obsolete in version 3.13.0:
  * add-decoding-of-vendor-specific-vpd-fields.patch
  * pciutils-3.1.7-fix-memory-leak-in-get_cache_name.patch
  * pciutils-3.2.0_update-dist.patch
  * pciutils-3.5.1-add-support-for-32-bit-pci-domains.patch
  * pciutils-lspci-Correct-Root-Capabilities-CRS-Software-Visibil.patch
  * show-gen4-speed-properly.patch
* Fri Jul 19 2024 Peter Simons <psimons@suse.com>
- Synchronize SLE-15 and openSUSE:Factory [jsc#PED-8393, bsc#1224138].
  The following patches are now obsolete in version 3.13.0:
  * lspci-Fixed-buffer-overflows-in-ls-tree.c.patch
  * pciutils-Add-PCIe-5.0-data-rate-32-GT-s-support.patch
  * pciutils-Add-PCIe-6.0-data-rate-64-GT-s-support.patch
  * pciutils-Add-decoding-of-vendor-specific-VPD-fields.patch
  * pciutils-VPD-Cleanup.patch
  * pciutils-VPD-When-printing-item-IDs-escape-non-ASCII-characte.patch
* Sun Jun 30 2024 Dirk Müller <dmueller@suse.com>
- update to 3.13.0:
  * lspci decodes CXL 1.1 device link status information.
  * Further development of the pcilmr (the link margining
    utility)
  * Dump parsing supports 6-digit domain numbers.
  * Bug fixes in PCIe link state reporting.
  * Decode more fields in PCIe AER capability.
  * Fixed build on Linux systems with musl libc.
  * Updated pci.ids.
* Sun Jun  9 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.12.0:
  * lspci decodes the IDE (Integrity & Data Encryption) and
    TEE-IO extended capabilities.
  * Optimization flags used for compiling individual object files
    should be the same as optimization flags for linking the final
    executable to make link-time optimization possible.
  * no longer look up subsystems in the HWDB
  * Updated pci.ids
- include changes from 3.11:
  * update-pciids now supports XZ compression
  * update-pciids now sends itself as the User-Agent.
  * Added a pcilmr utility for PCIe lane margining
  * ECAM back-end now scans ACPI and BIOS memory faster.
  * Linux systems without pread/pwrite are no longer supported
  * Improved decoding of PCIe control and status registers.
  * Decoding of CXL capabilities now supports up to CXL 3.0.
  * lspci now displays interrupt message numbers consistently across
    different capabilities.
  * Cache of IDs resolved via DNS, which was located in ~/.pci-ids
    by default, is now stored according to the XDG base directory
    specification in $XDG_CACHE_HOME/pci-ids.
  * All source files now have SPDX license identifiers.
  * various minor bug fixes and updated pci.ids.
* Wed Oct  4 2023 Peter Simons <psimons@suse.com>
- Apply "lspci-Fixed-buffer-overflows-in-ls-tree.c.patch" to fix a
  buffer overflow error that would cause lspci to crash on systems
  with complex topologies. [bsc#1215265]
- Add "pciutils.keyring" so that the tarball's signature can be
  verified at build time.
- Use "%%license" tag instead of "%%doc" to install the package's
  license file.
* Thu May 11 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.10.0:
  - Fixed bug in definition of versioned symbol aliases
    in shared libpci, which made compiling with link-time
    optimization fail.
  - Filters now accept "0x..." syntax for backward compatibility.
  - Windows: The cfgmgr32 back-end which provides the list of devices
    can be combined with another back-end which provides access
    to configuration space.
  - ECAM (Enhanced Configuration Access Mechanism), which is defined
    by the PCIe standard, is now supported. It requires root privileges,
    access to physical memory, and also manual configuration on some
    systems.
  - lspci: Tree view now works on multi-domain systems. It now respects
    filters properly.
  - Last but not least, pci.ids were updated to the current snapshot
    of the database. This includes overall cleanup of entries with
    non-ASCII characters in their names -- such characters are allowed,
    but only if they convey interesting information (e.g., umlauts
    in German company names, but not the "registered trade mark" sign).
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Fri Dec  2 2022 Dirk Müller <dmueller@suse.com>
- update to 3.9.0:
  * We decode Compute Express Link (CXL) capabilities.
  * The tree mode of lspci is now compatible with filtering options.
  * When setpci is used with a named register, it checks whether
    the register is present in the particular header type.
  * Linux: The intel-conf[12] back-ends prefer to use ioperm() instead
    of iopl() to gain access to I/O ports.
  * mmio-conf1(-ext): Added a new back-end implementing the intel-conf1
    interface over MMIO. This is useful on some ARM machines, but it
    requires manual configuration of the MMIO addresses.
  * As usually, updated pci.ids to the current snapshot of the database.
* Thu May 12 2022 Callum Farmer <gmbr3@opensuse.org>
- Make shared library executable
* Thu Apr 21 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.8.0:
  * Filters can now match devices based on partially specified
  class code and also on the programming interface.
  * Reporting of link speeds, power limits, and virtual function tags
  has been updated to the current PCIe specification.
  * We decode the Data Object Exchange capability.
  * Bus mapping mode works in non-zero domains.
  * pci_fill_info() can fetch more fields: bridge bases, programming
  interface, revision, subsystem vendor and device ID, OS driver,
  and also parent bridge. Internally, the implementation was rewritten,
  significantly reducing the number of corner cases to be handled.
  * If the configuration space is not readable for some reason
  (e.g., the cfgmgr32 back-end, but also badly implemented sleep mode
  of some devices), lspci prints only information provided by the OS.
  * The Hurd back-end was greatly improved thanks to Joan Lledó.
  * Various minor bug fixes and improvements.
  * As usually, updated pci.ids to the current snapshot of the database.
- Rebase pciutils-3.1.9_pkgconfig.patch
- Rebase pciutils-ocloexec.patch
- Rebase pciutils-endianh.patch
- Drop pciutils-add-decode-support-for-RCECs.patch
* Mon Jan 24 2022 vliaskovitis@suse.com
- Add "pciutils-Add-PCIe-5.0-data-rate-32-GT-s-support.patch" and
  "pciutils-Add-PCIe-6.0-data-rate-64-GT-s-support.patch" to fix
  LnkCap speed recognition in lspci for multi PCIe ports such as
  the ML110 Gen11. [bsc#1192862]
* Sun Jan 23 2022 Callum Farmer <gmbr3@opensuse.org>
- Set sbindir to /usr/bin to fix Steam issues
  (rh#1858437, gh#ValveSoftware/steam-for-linux#3306)
- Add symlinks from /usr/sbin to /usr/bin
* Tue May 11 2021 Callum Farmer <gmbr3@opensuse.org>
- prepare usrmerge (boo#1029961)
* Thu Oct 29 2020 pgajdos@suse.com
- Add decode support for RCECs [jsc#SLE-13735]
- added patches
  https://github.com/pciutils/pciutils/commit/e12bd01eea67ca8cf539263124843ba281eb6ecc
  + pciutils-add-decode-support-for-RCECs.patch
* Mon Jun  1 2020 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 3.7.0:
  * Add or improved the following capabilities:
    Designated Vendor-Specific, Compute eXpress Link,
    Resizable BARs, VF Resizable BARs, Link Capabilities 2,
    Link Status 2
  * On Linux, lspci can show IOMMU groups
  * setpci can be asked to skip bus scan and operate on a device
    completely specified by its domain/bus/dev/func address
  * back-ends which do not support domains now correctly fail when
    trying to access devices outside domain 0
- Add upstream keyging to verify source signature
* Thu May 21 2020 Michal Suchanek <msuchanek@suse.com>
- Fix lspci outputs few of the VPD data fields are displayed as unknown (bsc#1170554, ltc#185587).
  Added:
  * pciutils-VPD-When-printing-item-IDs-escape-non-ASCII-characte.patch
  * pciutils-VPD-Cleanup.patch
  * pciutils-Add-decoding-of-vendor-specific-VPD-fields.patch
* Thu Apr  2 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.6.4:
  * A new back-end for the GNU Hurd was contributed by Joan Lledó.
  * When printing VPD item identifiers, non-ASCII characters are escaped.
- Changes for version 3.6.3
  * `lspci -t' (tree mode) can be combined with `-s' to show a sub-tree.
    We also fixed potential buffer overflows in the tree dumper.
  * Cleaned messy code for dumping of I/O, memory, and ROM regions.
    This helped fixing a bug, which caused some 64-bit regions to be
    reported as virtual. All flags are now printed after the address
    (previously, "[virtual]" and "[enhanced]" were before it for no good
    reason).
  * Added pci_find_cap_nr() to the library, which handles capabilities
    which occur multiple times in a single device.
  * Minor improvements in printing of PCIe capabilities.
  * We now decode the Multicast and Secondary PCI Express extended
    capabilities.
  * The list of capability names available to setpci was updated.
  * Minor bugs were fixed in FreeBSD and Solaris ports.
  * We now prefer HTTPS URLs in all documentation
  * The pci.ids file has a man page.
  * As usually, updated pci.ids to the current snapshot of the database.
- Drop no longer relevant pciutils-3.2.0_update-dist.patch
- Do not ship update-pciids script - they are provided via hwdata
  package and we dont want to override data by other packages
* Thu Feb 28 2019 Martin Pluskal <mpluskal@suse.com>
- Replace dependency on pciutil-ids with hwdata
* Sun Sep 16 2018 Avindra Goolcharan <avindra@opensuse.org>
- Update to version 3.6.2
  * Added "-P" and "-PP" switches to lspci, which display the path
    through bridges to each device.
  * Fixed a couple of bugs in computation of bus topology. It was
    previously used only for the tree display, but we re-use it
    for computing the paths.
  * As usual, updated pci.ids to the current snapshot of the database.
- changes for version 3.6.0
  * BARs reported by the OS, but not set on the device itself are
    reliably marked with "[virtual]".
  * lib: Introduced a generic mechanism of string properties. This
    avoids lots of special cases and makes ABI compatibility easier.
  * On systems with OpenFirmware, report corresponding device tree
    nodes as device properties.
  * VPD decoder knows several non-standard extensions [bsc#1098228] (bsc#1170554, ltc#185587).
  * When PCIe link speed is less than the maximum supported by the
    device, it is explicitly marked as "downgraded".
  * Several new capabilities are not decoded yet, but at least
    their names are printed.
  * The Null capability is easily decoded.
  * Formatting of several capabilities was cleaned up.
  * The VGA16 bit in the bridge control register is now supported.
  * Added a port to SylixOS.
  * Added a port to DOS/DJGPP
  * The order in which back-ends are probed was decoupled from the
    internal back-end IDs. This helps, because new back-ends must
    have their ID allocated at the end to keep the ABI, but they
    might need to be proved earlier.
  * The fbsd-device back-end should work again.
  * Fixed a couple of bugs. Most notably, DeviceName was not printed.
- cleanup with spec-cleaner
- rebase pciutils-endianh.patch
* Wed Jun 27 2018 psimons@suse.com
- Apply "show-gen4-speed-properly.patch" from upstream to fix the
  display of the gen4 speed for GEN 4 cards like Mellanox CX5.
  [bsc#1098094]
- Apply "add-decoding-of-vendor-specific-vpd-fields.patch" to add
  support for commonly used vendor specific VPD keywords described
  in "Table 160. LoPAPR VPD Fields" of the Linux on Power
  Architecture Platform Reference (LoPAPR). [bsc#1098228]
* Sun Nov 19 2017 aavindraa@gmail.com
- Update to version 3.5.6
  * MN VPD keyword is decoded correctly.
  * As usual, updated pci.ids to the current snapshot of the
    database.
  * FreeBSD back-end: read-only access for non-root, support
    DragonFly BSD, support extended config space.
* Sat Nov 11 2017 aavindraa@gmail.com
- Update to version 3.5.5
  * Better decoding of AER capability.
  * "Slot Implemented" flag is decoded for PCI/PCI-X to PCIe bridges.
  * Minor fixes of decoding other capabilities.
  * As usual, updated pci.ids to the current snapshot of the
    database.
- cleanup with spec-cleaner
- switch from ftp to https
- track signature
* Mon Feb 27 2017 mpluskal@suse.com
- Update to version 3.5.4:
  * Previous version broke compilation on systems, for which
    lib/types.h did not provide a 64-bit integer type. It is
    provided everywhere now.
- Changes for version 3.5.3:
  * When lspci looks for Linux kernel modules, it uses the default
  path to module directory provided by libkmod. Previously,
  it tried to construct the path explicitly, which need not
  work on all systems.
  * Improved formatting of memory and I/O ranges behind a bridge.
  * PCIe link capabilities now display GEN4 speed (16GT/s) [bsc#1098094].
  * PCIe device capabilities now show bits related to atomic
    operations.
- Changes for version 3.5.2:
  * The L1 power management capability is now decoded more
  thoroughly. Thanks to Rajat Jain for the patch.
  * The table of configuration registers used by setpci
  had a bug in the definition of SUBSYSTEM_VENDOR_ID.
* Tue Dec  6 2016 psimons@suse.com
- Back-ported several changes from newer pciutils-3.5.1 to enable
  proper support for 32-bit PCI domain numbers (bsc#1006827) in
  pciutils-3.5.1-add-support-for-32-bit-pci-domains.patch.
* Tue Nov  1 2016 jlee@suse.com
- pciutils-lspci-Correct-Root-Capabilities-CRS-Software-Visibil.patch:
  lspci: Correct Root Capabilities "CRS Software Visibility" bit
  Found this issue when tracing bsc#1001888. (bsc#1001888)
* Wed May 25 2016 mpluskal@suse.com
- Update to version 3.5.1:
  * Fixed symbol versioning of pci_init().
* Fri May 20 2016 mpluskal@suse.com
- Update to version 3.5.0:
  * New capabilities decoded: Downstream Port Containment,
    Precision Time Measurement. Thanks to Keith Busch and
    Jonathan Yong.
  * Domain numbers extended to 31 bits. This will be used by the
    Linux kernel on some machines in near future (bsc#1006827).
  * Enhanced allocation regions are now decoded on Linux.
  * The NetBSD back-end supports PCIe extended configuration space.
  * Updated pci.ids to the current snapshot of the database.
* Fri Jan  8 2016 tchvatal@suse.com
- Version update to 3.4.1:
  * New capabilities decoded: Process Address Space, Page Request
    Interface, Enhanced Allocation. Thanks to David Daney and
    David Woodhouse.
  * DevCap SlotPowerLimit is now decoded for all components with
    upstream ports.
* Sat Nov 21 2015 jengelh@inai.de
- Summary update
* Fri Nov 13 2015 mpluskal@suse.com
- Update to 3.4.0
  * On Linux, we report NUMA nodes of devices.
  * The sysfs back-end does not die on read errors
    of optional attributes. Instead, a warning is produced.
  * Fixed several minor bugs.
  * Updated pci.ids to the current snapshot of the database.
* Sun Sep  6 2015 mpluskal@suse.com
- Update to 3.3.1
  * Removed hacks for backward compatibility with Linux libc5,
    which were breaking newer non-glibc Linux systems. Thanks
    to Felix Janda.
  * Display VirtIO vendor-specific capability. Patch by Gerd
    Hoffmann.
  * Fixed memory leak in name cache (bnc#837347).
  * Updated pci.ids to the current snapshot of the database.
* Thu Mar 12 2015 tchvatal@suse.com
- pciutils-3.1.7-fix-memory-leak-in-get_cache_name.patch: Fix
  a memory leak in get_cache_name (bnc#837347)
* Tue Nov 18 2014 tchvatal@suse.com
- Version bump to 3.3.0:
  * Device names exported by BIOS are displayed on Linux.
  * On Linux systems, HWDB is used to look up device names
    when our ID database gives no match. (More precisely,
    HWDB is consulted after local pci.ids, but before using
    network to query online pci.ids.) Thanks to Tom Gundersen
    for the initial patch.
  * Added experimental back-end for OS X / Darwin. Thanks to
    Richard Yao for providing it.
  * Filters now support matching by device class. Original
    patch by Matthew Wilcox, wrappers for ABI compatibility
    by me.
  * Interrupt Pin and Interrupt Line registers are displayed
    for bridge devices, too.
  * Several portability bugs have been fixed.
  * Several typos have been fixed. Also, use of questionable
    constructs in man pages has been reduced.
  * PCIe link capabilities now include the ASPMOptComp bit.
  * The "CRS Software Visibility" bit is now decoded properly (bsc#1001888).
  * Updated pci.ids to the current snapshot of the database.
- Refresh patch:
  * pciutils-endianh.patch
* Mon Aug 18 2014 fcrozat@suse.com
- Add obsoletes/provides to baselibs.conf.
* Tue May 13 2014 tchvatal@suse.com
- Remove COPYING from obs it is in tarball directly
- Version bump to 3.2.1:
  * CardBus bridge capabilities are displayed.
  * PCIe L1 PM substates are decoded.
  * Various bugs were fixed in decoding of PCIe capabilities.
  * The sysfs back-end does not spit out unnecessary warnings when
    empty slots report only a partial device address. This actually
    happens on IBM pSeries.
  * Updated pci.ids to the today's snapshot of the database.
- Cleanup with spec-cleaner
* Tue Jul 30 2013 sweet_f_a@gmx.de
- Update to 3.2.0
  * On newer Linux systems, we use libkmod to look up kernel
    modules (modules.pcimap no longer exists.) To facilitate this,
    libpci is able to look up module aliases in sysfs.
  * Various minor bug fixes.
  * Updated pci.ids to the today's snapshot of the database.
- Update to 3.1.10
  * Decoding of LTR/OBFF in PCIe capabilities.
  * Various minor bug fixes.
  * Updated pci.ids to the today's snapshot of the database.
- rebase patches
- require libkmod
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Mon Dec 31 2012 crrodriguez@opensuse.org
- pciutils-endianh.patch Use the documented/optimized byteswapping
  routines from endian.h
* Sun Mar 18 2012 jengelh@medozas.de
- Shared library policy: new subpackage libpci3
* Sun Jan 29 2012 tabraham@novell.com
- Update to 3.1.9
  * Whereever we mention the PCI ID database, we now refer to
    http://pci-ids.ucw.cz/ and the sf.net site is mentioned only
    as a mirror. This includes update-pciids.
  * Decode PCIe Gen 3 speeds and link status fields
  * various minor bug fixes
  * Updated pci.ids to the 2012-01-14 snapshot of the database
- Update to 3.1.8
  * More capabilities: Transaction Processing Hints, Latency
    Tolerance Reporting. Thanks to Jesse Barnes.
  * Added BeOS and Haiku ports. Contributed by Francois Revol.
  * pciutils.pc now uses Libs.private properly.
  * When we format a name and it does not fit in the buffer, we
    truncate it instead of returning "buffer too small" instead.
    This works on all platforms with sane (i.e., C99-compatible)
    snprintf().
  * various minor bug fixes
* Mon Nov 14 2011 crrodriguez@opensuse.org
- open all file descriptors with O_CLOEXEC,specially important
  on libpci and calling apps may fork() and we end up leaking
  information to child processes.
* Mon Mar 21 2011 coolo@novell.com
- licenses package is about to die
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Thu Feb 25 2010 anicka@suse.cz
- update to 3.1.7
  * Minor improvements and bug fixes in decoding of the Virtual Channel
  capability.
  * Released as 3.1.6.
  * More capabilities decoded: Virtual Channel (except arbitration
  tables), Root Complex Link, Vendor-Specific (header only), SATA HBA.
  * All extended capabilities have their version displayed (-vv or more).
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Fri Jan 22 2010 anicka@suse.cz
- update to 1.3.5
  * Updated pci.ids to the today's snapshot of the database.
  * When scanning extended capabilities, properly mask the lowest 2 bits,
  which are currently reserved. This avoids unaligned access errors on
  broken hardware (see tests/broken-ecaps).
  * Large bar sizes are displayed in human-readable format (with units).
  * Physical slot information is displayed correctly for multi-function cards.
  * Fixed a couple of typos everywhere.
  * Library: Fixed bugs in freeing of capabilities.
  * Windows back-end compiles again.
* Tue Dec 15 2009 jengelh@medozas.de
- enable parallel building
* Thu Dec 10 2009 anicka@suse.cz
- update to 3.1.4
  * Updated pci.ids to the today's snapshot of the database.
  * Fixed memory and file descriptor leak in the dump back-end.
  * The SR-IOV capability decoder now prints the VF BAR's.
  * On request of certain company's lawyers, we now include a copy
  of the GPL with our package. It seems that the pciutils are getting
  mature if the most important bug of the month was this one ;-)
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Fri Aug 14 2009 anicka@suse.cz
- add COPYING file to fix (bnc#518238)
- fix last patch
* Mon Aug 10 2009 anicka@suse.cz
- add fclose to dump_init (bnc#529469)
* Mon Aug  3 2009 anicka@suse.cz
- update to 3.1.3
  * The VPD parser now reports unknown and vendor-defined items
  properly. It also stops on any item in unknown format,
  avoiding long output on bogus VPD data.
  * The MSI-X table size now matches the spec.
  * The Power Management capability now includes the soft reset bit.
  * Decoding of the Advanced Features capability has been added.
  * The whole package compiles on GNU/kFreeBSD again.
  * The procfs back-end is able to cope with /proc/bus/pci
  containing names with domains, which occur on sparc64 and
  possibly other architectures due to a kernel bug.
  * The sysfs back-end no longer complains when a slot address
  is missing, which happens with old versions of Linux fakephp.
  * The Device Serial Number capability is printed in the right
  byte order.
  * The MSI and MSI-X capabilities are printed in a prettier way.
  * The tree output mode (`lspci -t') shows domain numbers only
  at the root, which makes the output more compact.
  * Updated documentation on the bus mapping mode (`lspci -M').
* Thu Feb  5 2009 anicka@suse.cz
- update to 3.1.2
  * Fixed another silly bug in the command-line parser of setpci.
  * The configure script now sets LC_ALL to avoid being fooled by
  locale-dependent behavior of `tr'.
  * The command-line parser of setpci did sometimes segfault on invalid
  input.
  * The Cygwin backend now works on Windows Vista.
  * Fixed a bug in decoding of the SR-IOV capability.
  * Details of some PCIe capabilities are displayed only with -vv.
  * When a BAR is reported by the OS, but not by the device (i.e.,
  it is marked as [virtual] in lspci), the [disabled] flag is
  suppressed, because it does not make sense in such cases.
  * The source code of lspci has been split to multiple files, hopefully
  making it easier to maintain.
  * The library and lspci now know about physical slot names. So far,
  they are provided by the sysfs back-end only.
  * When a device has the VPD (Vital Product Data) capability and the
  VPD data are supplied by the OS, they are decoded and printed in the
  verbose mode. This currently works only on Linux with the sysfs
  back-end.
  * `setpci --version' now works properly.
  * `setpci --dumpregs' prints a table of all known names of
  registers and capabilities. This replaces the table of registers
  in the setpci man page.
  * The dry-run mode of setpci gives better feedback.
  * The setpci utility is now able to address registers stored in PCI
  capabilities (actually it allows a more general form of relative
  addressing).
  * The library has gained functions for working with PCI capabilities.
  * Address Translation Services capability is now decoded.
  * `lspci -k' now displays the subsystem ID, too. This makes `-k'
  show everything needed to identify the device and the available
  drivers, which was called for by many users.
  * Fixed spelling of MSI.
  * Better support for cross-compilation.
  * Fixed printing of the AER capability.
  * HT 1.02 capabilities are decoded as HT 1.03.
  * Fixed Cygwin build.
  * Fixed a minor bug in the configure script, which caused warnings
  about redefinition of symbols during compilation.
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Sep 11 2008 anicka@suse.cz
- update to 3.0.1
  * Added a Cygwin port.
  * Worked around compatibility problems with various default
  settings of wget
  * Fixed printing of MSI capabilities.
  * Added decoding of several PCI-X capabilities: device/link/slot 2,
  Advanced Error Reporting, Access Control Services, Alternative
  Routing-ID, Single Root I/O Virtualization.
  * Fixed bug in filters which caused them to refuse
  vendor/device ID 0xffff.
  * Fixed several build problems: builds without PCI_USE_DNS
  on Linux and with PCI_USE_DNS on Solaris and *BSD. Static
  library mode also compiles again on old versions of GCC.
* Fri Apr 11 2008 mrueckert@suse.de
- move shared libs to /%%{_lib}
- added pciutils-3.0.0_pkgconfig.patch:
  clean up the pkgconfig file so we can include it
- package the pkgconfig file
* Thu Apr 10 2008 mrueckert@suse.de
- if we no longer provide the static lib we should at least provide
  the symlink to link against libpci
* Thu Apr 10 2008 anicka@suse.cz
- update to 3.0.0
  * The makefile system has been reworked. All configuration
  settings are now passed to the configure script in environment
  variables, allowing for easy tweaking in the top-level Makefile.
  All control knobs are now described in the README.
  * The libpci can be built as a shared library with properly
  restricted symbol exports. Use `make SHARED=yes' to enable that
  or `make SHARED=local' for a local testing build (with hardwired
  paths to the library, so that it does not need installation).
  * Support for resolving of PCI ID's using DNS together with a local
  cache of resolved entries has been added. See the `-q' and `-Q'
  options of lspci.
  * The library now has a generic system of settable parameters, which
  also include settings of the DNS resolver and cache. An `-O'
  option has been added to lspci and setpci to allow setting
  of these options.
  * Configuration of the access methods are now specified by the new
  parameter system, replacing the pci_access->method_params array.
  * Access methods now also have sensible names and help texts and it
  is possible to look up method ID by a name.
  * An `-A' switch has been added to both lspci and setpci, allowing
  to select an arbitrary access method. The `-P' switch (configure
  proc backend) has been removed as it is no longer needed
  and I do not know any its user.
  * Several source files have been split for better maintainability
  (most notably the resolving of ID's).
  * Man pages and help texts have been updated. A new man page
  `pcilib(7)' has been added and description of library options
  has been moved there.
  * When an unknown device ID is encountered, we print `Device <id>'
  instead of `Unknown device <id>'. It uses less space and it also
  should reduce the number of inexperienced users complaining that
  the device is not supported by the OS. To lookup up OS drivers,
  use the `-k' option.
  * Makefile: stripping of the binaries during installation can be
  overridden by the STRIP variable.
  * lib/types.h: We use the integer types from <stdint.h> if the
  compiler claims C99 support.
- remove strip patch
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Apr  9 2008 anicka@suse.cz
- update to 2.2.10
  * lspci.c, setpci.c: Cleaned up the list of options.
  * lib/names.c: Fix displaying of errors reported by zlib.
  Previously, the buffer containing the error message had
  been deallocated by gzclose() before the message was printed.
  * update-pciids.sh: Added quiet mode (-q). Clean up uncompressed
  files left by previous versions of the pciutils.
  * update-pciids.man: Mention the -q switch.
  * lib/dump.c: Squashed compiler warnings about code with
  no effect (there really were surplus *'s).
* Tue Nov  6 2007 anicka@suse.cz
- update to 2.2.9
  * lspci.c: Added a new switch `-k' which requests printing
    of information on kernel drivers attached to each device
    and on kernel modules reporting the ability to handle the
    device.
  * Makefile, lib/Makefile: Moved -lz from LDFLAGS to LDLIBS.
    Also added an explicit pattern rule for linking to make sure
    that LDLIBS is used on all platforms.
  * pci.ids: Revised class codes to match Conventional PCI 3.0
    specs.
  * lspci.c: Decode the Debug port capability (per EHCI 0.96 spec).
  * lspci.c: Big code cleanup: re-arranged functions in the code,
    renamed everything related to capabilities to cap_* and
    all options except verbose to opt_*.
  * Capability loop detection introduced 2.2.7 did not work
    properly with extended capabilities. Fixed.
* Wed Oct 24 2007 anicka@suse.cz
- drop the patch backporting upstream bug in
  a machine readable output [#330533]
- fix typo in show_ext_caps in lspci
* Fri Oct  5 2007 anicka@suse.cz
- update to 2.2.7
  * lspci.c (show_caps, show_ext_caps): Detect and report loops in
    capability lists.
  * lspci.c, lib/header.h: Finished decoding of the PCI Express
    capability. The extended capabilities remain undecoded for now,
    but at least the list of them has been updated to reflect the
    current PCI Express 2.0 spec.
  * lspci.c, lib/header.h: Decode new bits of traditional registers
    as defined by PCIE / PCI-X. This includes discard timers in
    the bridge control register and INTx enable/status in device
    control/status registers.
  * Makefile, lib/Makefile: `ar' and `ranlib' can be overriden to
    allow cross-compilation.
  * lspci.c (show_ht): Added decoding of Hypertransport MSI
    mapping capability
  * tests/cap-MSI-mapping: Added a test case.
* Tue Jul  3 2007 anicka@suse.cz
- update to 2.2.6
  * Makefile: Added an "install-lib" target.
  * Makefile, lib/Makefile: Generate and install pkg-config file
  for libpci.
  * lib/i386-io-hurd.h: Rewritten for new Hurd kernels.
* Fri May  4 2007 anicka@suse.cz
- update to 2.2.5
  * pci.ids: Updated to the current snapshot of the database.
  * lspci.c (show_express): Added PCI/PCI-X to PCI-Express
    Bridge type.
  * pci.ids: Updated to the current snapshot of the database.
  * Replaced bzero() by memset() everywhere, it's better to lose
    a tiny bit of readability than maintain hacks to make it work
    on various systems.
  * lib/configure: tr on Solaris is a bit weird and it requires
    `[A-Z]' instead of `A-Z'. Fortunately, the extra brackets
    don't hurt otherwise.
  * lib/types.h, lib/configure: Solaris should use <stdint.h>
    to get precise integer types.
  * lspci.c: alloca() needs <alloca.h>.
  * lib/dump.c: Fixed a couple of bugs in the dump backend which
    caused devices with domains or with extended config space
    to be read incorrectly. Also, dumps with partial lines are
    allowed now.
  * lspci.c (scan_device): If an error occurs when reading the
    standard config header of a device, report it and ignore the
    device and return with exit code 2 at the end.
- remove noabort.diff (implemented by upstream)
* Thu Mar 29 2007 rguenther@suse.de
- add zlib-devel BuildRequires
- require zlib-devel from pciutils-devel package
* Mon Jan 29 2007 anicka@suse.cz
- change dependency from python to perl in update-pciids [#221276]
* Sat Jan 20 2007 garloff@suse.de
- Change update-pciids to download to pci.ids.d/pci.ids.dist
  and call merge-pciids if possible. [FATE 301145, bug 221276]
* Fri Oct 13 2006 aj@suse.de
- Fix to build (remove pci.ids.gz as well).
* Fri Oct 13 2006 mjancar@suse.cz
- update to 2.2.4
  * many bugfixes and cleanups
- branch separate package for pci.ids
* Mon May 22 2006 schwab@suse.de
- Don't strip binaries.
* Wed Mar 22 2006 kukuk@suse.de
- Remove pciids-suse patch (has to be fixed upstream)
* Wed Mar 22 2006 kukuk@suse.de
- Auto-Update pci.ids
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 mjancar@suse.cz
- update pci.ids (#144200)
* Fri Jan 13 2006 mjancar@suse.cz
- reintroduce "Class" printed in numeric output (#143042)
* Mon Dec 19 2005 mjancar@suse.cz
- update to 2.2.1
* Fri Aug 26 2005 mjancar@suse.cz
- add types.h to pciutils-devel (#113294)
* Wed Aug 24 2005 mjancar@suse.cz
- update to 2.1.99-test9 (#98896)
- update pci.ids (#104381)
* Mon Mar 14 2005 mjancar@suse.cz
- fix non-ascii characters in pci.ids (#72345)
* Sat Mar  5 2005 schwab@suse.de
- Fix syntax error in pci.ids.
* Tue Feb 22 2005 mjancar@suse.cz
- fix sysfs parsing (#63326)
- update pci.ids
* Fri Sep 17 2004 tcrhak@suse.cz
- updated pci.ids to the latest snapshot (fixes bug #45370)
* Thu May 27 2004 tcrhak@suse.cz
- changed "SGI IO9/IO10 Gigabit Ethernet (Copper)"
  to "SGI IO9/IO10 Gigabit Ethernet (Copper)" (bug #40175)
* Wed Apr 28 2004 tcrhak@suse.cz
- updated pci.ids
* Thu Mar  4 2004 tcrhak@suse.cz
- some pci.ids fixes:
  * changed SubDevice of Dell Inspiron 2100 internal modem (bug #32842)
  * added 1291 - Auxiliary Diva Serial Port (bug #31984)
  * added PCI IDs for InfiniBand HCAs (bug #34928)
* Tue Feb 24 2004 tcrhak@suse.cz
- added support for domains to device filter (lspci -s, setpci -s)
  (fixes bug #33382, patch sysfs-filter)
- updated pci.ids
* Sat Nov 29 2003 olh@suse.de
- use default owner for pciutils-devel files
* Wed Nov  5 2003 olh@suse.de
- remove pcimodules again, it doesnt do anything right
* Tue Oct 28 2003 olh@suse.de
- add patch for 2.6 /proc/bus/pci layout
  http://ftp.linux.org.uk/pub/linux/willy/patches/pciutils-sysfs.diff
* Wed Oct  8 2003 tcrhak@suse.cz
- added pcimodules [bug #31953]
* Mon Aug 25 2003 tcrhak@suse.cz
- updated pci.ids to the latest version from http://pciids.sourceforge.net
* Tue Feb 18 2003 tcrhak@suse.cz
- fixed NIC PCI IDs for Compaq [bug #22795],
  patch pciids.diff
- also included the diff for the latest pci.ids
  into the patch
* Wed Jan 15 2003 tcrhak@suse.cz
- fixed install paths
* Mon Jan  6 2003 tcrhak@suse.cz
- update to version 2.1.11
- updated pci.ids to the latest version from http://pciids.sourceforge.net
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Sep  6 2002 olh@suse.de
- update description of pcnet32 cards (#18892)
* Thu Aug 29 2002 tcrhak@suse.cz
- updated pci.ids to latest version from http://pciids.sourceforge.net
  this version contains entries needed by Hammer systems (bug #17549)
* Thu Aug  8 2002 olh@suse.de
- the acenic gigabit card can be either fibre or utp
  update pci.ids entry (#17502)
* Tue Jul 30 2002 tcrhak@suse.cz
- updated to version 2.1.10
- updated pci.ids to latest version from http://pciids.sourceforge.net
* Tue Mar 26 2002 tcrhak@suse.cz
- updated pci.ids to latest version from http://pciids.sourceforge.net
* Fri Jan 18 2002 tcrhak@suse.cz
- used macros %%{_lib} and %%{_libdir}
* Tue Jan  8 2002 schwab@suse.de
- Fix warnings.
* Mon Dec 17 2001 tcrhak@suse.cz
- updated pciutils to 2.1.9
- updated pci.ids to latest version from
  http://pciids.sourceforge.net/
* Wed Dec 12 2001 grimmer@suse.de
- updated pci.ids to latest version from
  http://pciids.sourceforge.net/
- added pci.ids.bz2 as a separate source file and removed
  pci.ids.add.dif (now included upstream)
* Mon Sep 24 2001 grimmer@suse.de
- added some missing PCI IDs for LSI Logic Fibre Channel
  controllers to pci.ids.add.diff
- corrected typos in pci.ids (Fiber Channel -> Fibre Channel)
- added LSI Logic Inc. to vendor ID 0x1000
* Wed Sep 19 2001 grimmer@suse.de
- added some missing PCI IDs for Compaq NICs to pci.ids.add.diff
  see [#8918] for the list
* Mon Sep 10 2001 grimmer@suse.de
- corrected some Intel NIC entries upon request from Intel
- merged pci.ids.riva.diff and the Intel changes in pci.ids.add.diff
* Mon Sep  3 2001 garloff@suse.de
- Riva TnT corrections from snbarth:
  * The name of Riva TnT 128 is Riva TnT.
  * NVidia/SGS Joint Venture (12d2) never built TNT or later.
* Wed Aug 29 2001 grimmer@suse.de
- merged pci.ids.244ac6.diff and pci.ids.add.diff into a single
  patch (again named pci.ids.add.diff) and added some more PCI IDs
  collected by Dave Jones <davej@suse.de> from various sources,
  including the current pciutils CVS tree.
- beautyfied the spec file a bit (added clean section and defattr
  in file list)
* Mon May 21 2001 poeml@suse.de
- add -devel subpackage
* Thu May 10 2001 garloff@suse.de
- Merge pci.ids from 2.4.4ac6
- bzip2 tarball
* Thu May  3 2001 garloff@suse.de
- Also don't die on failing to read data of a normal device,
  just complain loudly (and return 2 in the end)
- Updated pci.ids from linux-2.4.4 and added DFE-660.
* Wed Jan 17 2001 garloff@suse.de
- Don't die on failure to read ext. cardbus data. [#5817]
* Sun Dec 17 2000 garloff@suse.de
- Added pci.ids from linux-2.4.0-test12
- Added pci.ids floating around (lkml, RH)
- Added pci.ids for i820, ICH2/-M
* Mon Sep 18 2000 schwab@suse.de
- Add `-Wno-format' to avoid spurious compile errors.
* Thu Aug 17 2000 ro@suse.de
- cleanup srcdir
* Sun Jun 11 2000 olh@suse.de
- update to 2.1.8
* Mon Jan 24 2000 aj@suse.de
- update to 2.1.4, fix build problems with latest glibc, use patch
  for make file from Martin Mares.
* Thu Jan 20 2000 aj@suse.de
- update to 2.1.3, /usr/man -> /usr/share/man
* Tue Jan  4 2000 ro@suse.de
- update to 2.1.2
* Mon Oct 25 1999 ro@suse.de
- fixed to compile on axp
* Sat Oct 23 1999 ro@suse.de
- update to 2.1pre8 / using Buildroot
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu May 20 1999 ro@suse.de
- update to 2.0
* Wed Mar 31 1999 bs@suse.de
- don't use lx_hack for build
* Mon Feb 22 1999 ro@suse.de
- update to 1.10
* Wed Nov 25 1998 ro@suse.de
- created package, version 1.08
